==> rivendell-3.4.0.tar.gz: rivendell-3.4.0/rdadmin/add_feed.h <==
// add_feed.h
//
// Add a Rivendell Feed
//
//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License version 2 as
//   published by the Free Software Foundation.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public
//   License along with this program; if not, write to the Free Software
//   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef ADD_FEED_H
#define ADD_FEED_H

#include <qcheckbox.h>
#include <qlineedit.h>

#include <rddialog.h>

//
// Default XML Templates
//
#define DEFAULT_HEADER_XML "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n<rss version=\"2.0\">"
#define DEFAULT_CHANNEL_XML "<title>%TITLE%</title>\n<description>%DESCRIPTION%</description>\n<category>%CATEGORY%</category>\n<link>%LINK%</link>\n<language>%LANGUAGE%</language>\n<copyright>%COPYRIGHT%</copyright>\n<lastBuildDate>%BUILD_DATE%</lastBuildDate>\n<pubDate>%PUBLISH_DATE%</pubDate>\n<webMaster>%WEBMASTER%</webMaster>\n<generator>%GENERATOR%</generator>"
#define DEFAULT_ITEM_XML "<title>%ITEM_TITLE%</title>\n<link>%ITEM_LINK%</link>\n<guid isPermaLink=\"false\">%ITEM_GUID%</guid>\n<description>%ITEM_DESCRIPTION%</description>\n<author>%ITEM_AUTHOR%</author>\n<comments>%ITEM_COMMENTS%</comments>\n<source url=\"%ITEM_SOURCE_URL%\">%ITEM_SOURCE_TEXT%</source>\n<enclosure url=\"%ITEM_AUDIO_URL%\" length=\"%ITEM_AUDIO_LENGTH%\"  type=\"audio/mpeg\" />\n<category>%ITEM_CATEGORY%</category>\n<pubDate>%ITEM_PUBLISH_DATE%</pubDate>"

class AddFeed : public RDDialog
{
  Q_OBJECT
  public:
   AddFeed(unsigned *id,QString *keyname,QWidget *parent=0);
   ~AddFeed();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;

  private slots:
   void okData();
   void cancelData();

  private:
   QCheckBox *feed_users_box;
   QLineEdit *feed_keyname_edit;
   QString *feed_keyname;
   unsigned *feed_id;
};


#endif  // ADD_FEED_H

==> rivendell-3.5.0.tar.gz: rivendell-3.5.0/rdadmin/add_feed.h <==
// add_feed.h
//
// Add a Rivendell Feed
//
//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License version 2 as
//   published by the Free Software Foundation.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public
//   License along with this program; if not, write to the Free Software
//   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef ADD_FEED_H
#define ADD_FEED_H

#include <qcheckbox.h>
#include <qcombobox.h>
#include <qlineedit.h>
#include <qlabel.h>
#include <qpushbutton.h>

#include <rddialog.h>

class AddFeed : public RDDialog
{
  Q_OBJECT
 public:
  AddFeed(unsigned *id,QString *keyname,QWidget *parent=0);
  ~AddFeed();
  QSize sizeHint() const;
  QSizePolicy sizePolicy() const;

 private slots:
  void keynameChangedData(const QString &str);
  void okData();
  void cancelData();

 protected:
  void resizeEvent(QResizeEvent *e);

  private:
   QLabel *feed_keyname_label;
   QLineEdit *feed_keyname_edit;
   QCheckBox *feed_users_box;
   QLabel *feed_users_label;
   QPushButton *feed_ok_button;
   QPushButton *feed_cancel_button;
   QString *feed_keyname;
   unsigned *feed_id;
};


#endif  // ADD_FEED_H
